# Zuken
Small Python library for Zuken.
Contains a variety of functions that I have found to be useful while creating scripts for Zuken at work.

Will be updated as I find new things to include that I find useful.

Tests aren't included yet, as it requires manual testing due to the integration with Zuken itself.
